/*
 * Copyright (c) 2011 Imre Fazekas.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the Brillien nor the names of its
 * terms and concepts may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.vii.brillien.kernel.axiom.atomic.shaper.filters;

import com.vii.brillien.kernel.BrillienException;
import com.vii.brillien.kernel.axiom.atomic.shaper.Filter;

/**
 * Spcialized Filter type for filtering by error code
 */
public class ErrorCodeFilter implements Filter {

    public static final byte MODE_EQUAL             = 0;
    public static final byte MODE_NOT_EQUAL         = 1;
    public static final byte MODE_LESS_OR_EQUAL     = 2;
    public static final byte MODE_LESS_THAN         = 3;
    public static final byte MODE_GREATER_OR_EQUAL  = 4;
    public static final byte MODE_GREATER_THAN      = 5;

    protected int     codeLB;
    protected int     codeUB;
    protected byte    mode;

    {
        codeLB  = Integer.MIN_VALUE;
        codeUB  = Integer.MIN_VALUE;
        mode    = MODE_EQUAL;
    }

    public ErrorCodeFilter(int codeLB) {
        this.codeLB = codeLB;
    }

    public ErrorCodeFilter(int codeLB, byte mode) {
        this.codeLB = codeLB;
    }

    public ErrorCodeFilter(int codeLB, int codeUB) {
        this.codeLB = codeLB;
        this.codeUB = codeUB;
    }

    protected boolean innerInterest( BrillienException be ){
        switch ( mode ){
            case MODE_EQUAL: return be.getErrorCode() == codeLB;
            case MODE_NOT_EQUAL: return be.getErrorCode() != codeLB;
            case MODE_LESS_OR_EQUAL: return be.getErrorCode() <= codeLB;
            case MODE_LESS_THAN: return be.getErrorCode() < codeLB;
            case MODE_GREATER_OR_EQUAL: return be.getErrorCode() >= codeLB;
            case MODE_GREATER_THAN: return be.getErrorCode() > codeLB;
        }
        return false;
    }

    @Override
    public boolean interestedIn(BrillienException be) {
        return  codeUB == Integer.MIN_VALUE
                ? innerInterest( be )               
                : be.getErrorCode() >= codeLB && be.getErrorCode() <= codeUB;
    }

    @Override
    public String toString() {
        return "ErrorCodeFilter{" +
                "codeLB=" + codeLB +
                ", codeUB=" + codeUB +
                ", mode=" + mode +
                '}';
    }
    
}
